[gthumb] gio utils: use the _g_file prefix fir functions that take a GFile object



commit 2833417fd3987941f097eaf978dc687389d2743e
Author: Paolo Bacchilega <paobac src gnome org>
Date:   Wed May 9 15:20:05 2012 +0200

    gio utils: use the _g_file prefix fir functions that take a GFile object

 extensions/cairo_io/cairo-io-jpeg.c                |   10 +-
 extensions/catalogs/callbacks.c                    |   14 ++--
 extensions/catalogs/dlg-add-to-catalog.c           |   16 ++--
 extensions/catalogs/dlg-catalog-properties.c       |   16 ++--
 extensions/catalogs/gth-catalog.c                  |   36 ++++----
 extensions/catalogs/gth-file-source-catalogs.c     |   84 ++++++++++----------
 extensions/comments/gth-comment.c                  |   16 ++--
 extensions/comments/gth-import-metadata-task.c     |   26 +++---
 .../comments/gth-metadata-provider-comment.c       |    2 +-
 extensions/contact_sheet/dlg-contact-sheet.c       |   24 +++---
 .../contact_sheet/gth-contact-sheet-creator.c      |   14 ++--
 .../edit_metadata/gth-delete-metadata-task.c       |   26 +++---
 .../exiv2_tools/gth-metadata-provider-exiv2.c      |   16 ++--
 extensions/facebook/facebook-service.c             |   14 ++--
 extensions/flicker_utils/dlg-import-from-flickr.c  |    2 +-
 extensions/flicker_utils/flickr-service.c          |   14 ++--
 extensions/image_rotation/rotation-utils.c         |   26 +++---
 extensions/importer/gth-import-task.c              |   30 ++++----
 extensions/list_tools/gth-script-file.c            |    4 +-
 extensions/oauth/oauth-authentication.c            |    4 +-
 extensions/photobucket/photobucket-service.c       |   10 +-
 extensions/picasaweb/dlg-import-from-picasaweb.c   |    2 +-
 .../picasaweb/picasa-account-properties-dialog.c   |   10 +-
 extensions/picasaweb/picasa-web-service.c          |   14 ++--
 extensions/search/actions.c                        |   10 +-
 extensions/search/gth-search-task.c                |   32 ++++----
 gthumb/gio-utils.c                                 |   54 ++++++------
 gthumb/gio-utils.h                                 |    8 +-
 gthumb/gth-filter-file.c                           |    4 +-
 gthumb/gth-pixbuf-list-task.c                      |   10 +-
 gthumb/gth-tags-file.c                             |    4 +-
 gthumb/main-migrate-catalogs.c                     |   24 +++---
 gthumb/pixbuf-io.c                                 |   16 ++--
 33 files changed, 296 insertions(+), 296 deletions(-)
---
diff --git a/extensions/cairo_io/cairo-io-jpeg.c b/extensions/cairo_io/cairo-io-jpeg.c
index 3e47fb7..acf15fa 100644
--- a/extensions/cairo_io/cairo-io-jpeg.c
+++ b/extensions/cairo_io/cairo-io-jpeg.c
@@ -171,11 +171,11 @@ _cairo_image_surface_create_from_jpeg (GthFileData   *file_data,
 
 	image = gth_image_new ();
 
-	if (! g_load_file_in_buffer (file_data->file,
-			      	     &in_buffer,
-			      	     &in_buffer_size,
-			      	     cancellable,
-			      	     error))
+	if (! _g_file_load_in_buffer (file_data->file,
+			      	      &in_buffer,
+			      	      &in_buffer_size,
+			      	      cancellable,
+			      	      error))
 	{
 		return image;
 	}
diff --git a/extensions/catalogs/callbacks.c b/extensions/catalogs/callbacks.c
index 4c0c9fc..cf37e86 100644
--- a/extensions/catalogs/callbacks.c
+++ b/extensions/catalogs/callbacks.c
@@ -804,13 +804,13 @@ process_rename_data_list (gpointer user_data)
 
 		gio_file = gth_catalog_file_to_gio_file (rename_data->location);
 		catalog_data = gth_catalog_to_data (catalog, &catalog_data_size);
-		if (! g_write_file (gio_file,
-				    FALSE,
-				    G_FILE_CREATE_NONE,
-				    catalog_data,
-				    catalog_data_size,
-				    NULL,
-				    &error))
+		if (! _g_file_write (gio_file,
+				     FALSE,
+				     G_FILE_CREATE_NONE,
+				     catalog_data,
+				     catalog_data_size,
+				     NULL,
+				     &error))
 		{
 			g_warning ("%s", error->message);
 			g_clear_error (&error);
diff --git a/extensions/catalogs/dlg-add-to-catalog.c b/extensions/catalogs/dlg-add-to-catalog.c
index 9d62eb7..77f6c67 100644
--- a/extensions/catalogs/dlg-add-to-catalog.c
+++ b/extensions/catalogs/dlg-add-to-catalog.c
@@ -144,14 +144,14 @@ catalog_ready_cb (GObject  *catalog,
 
 	buffer = gth_catalog_to_data (add_data->catalog, &length);
 	gio_file = gth_catalog_file_to_gio_file (add_data->catalog_file);
-	g_write_file_async (gio_file,
-			    buffer,
-			    length,
-			    TRUE,
-			    G_PRIORITY_DEFAULT,
-			    NULL,
-			    catalog_save_done_cb,
-			    add_data);
+	_g_file_write_async (gio_file,
+			     buffer,
+			     length,
+			     TRUE,
+			     G_PRIORITY_DEFAULT,
+			     NULL,
+			     catalog_save_done_cb,
+			     add_data);
 
 	g_object_unref (gio_file);
 }
diff --git a/extensions/catalogs/dlg-catalog-properties.c b/extensions/catalogs/dlg-catalog-properties.c
index a8d3659..d2a0974 100644
--- a/extensions/catalogs/dlg-catalog-properties.c
+++ b/extensions/catalogs/dlg-catalog-properties.c
@@ -127,14 +127,14 @@ save_button_clicked_cb (GtkButton  *button,
 
 	gio_file = gth_catalog_file_to_gio_file (data->file_data->file);
 	buffer = gth_catalog_to_data (data->catalog, &size);
-	g_write_file_async (gio_file,
-			    buffer,
-			    size,
-			    TRUE,
-			    G_PRIORITY_DEFAULT,
-			    NULL,
-			    catalog_saved_cb,
-			    data);
+	_g_file_write_async (gio_file,
+			     buffer,
+			     size,
+			     TRUE,
+			     G_PRIORITY_DEFAULT,
+			     NULL,
+			     catalog_saved_cb,
+			     data);
 
 	g_object_unref (gio_file);
 }
diff --git a/extensions/catalogs/gth-catalog.c b/extensions/catalogs/gth-catalog.c
index d4b887f..2bc83c0 100644
--- a/extensions/catalogs/gth-catalog.c
+++ b/extensions/catalogs/gth-catalog.c
@@ -582,11 +582,11 @@ gth_catalog_list_async (GthCatalog           *catalog,
 	list_data->list_ready_func = ready_func;
 	list_data->user_data = user_data;
 
-	g_load_file_async (catalog->priv->file,
-			   G_PRIORITY_DEFAULT,
-			   catalog->priv->cancellable,
-			   list__catalog_buffer_ready_cb,
-			   list_data);
+	_g_file_load_async (catalog->priv->file,
+			    G_PRIORITY_DEFAULT,
+			    catalog->priv->cancellable,
+			    list__catalog_buffer_ready_cb,
+			    list_data);
 }
 
 
@@ -1072,11 +1072,11 @@ gth_catalog_load_from_file_async (GFile         *file,
 	load_data->user_data = user_data;
 
 	gio_file = gth_catalog_file_to_gio_file (file);
-	g_load_file_async (gio_file,
-			   G_PRIORITY_DEFAULT,
-			   cancellable,
-			   load__catalog_buffer_ready_cb,
-			   load_data);
+	_g_file_load_async (gio_file,
+			    G_PRIORITY_DEFAULT,
+			    cancellable,
+			    load__catalog_buffer_ready_cb,
+			    load_data);
 
 	g_object_unref (gio_file);
 }
@@ -1129,7 +1129,7 @@ gth_catalog_load_from_file (GFile *file)
 	gsize       buffer_size;
 
 	gio_file = gth_catalog_file_to_gio_file (file);
-	if (! g_load_file_in_buffer (gio_file, &buffer, &buffer_size, NULL, NULL))
+	if (! _g_file_load_in_buffer (gio_file, &buffer, &buffer_size, NULL, NULL))
 		return NULL;
 
 	catalog = gth_hook_invoke_get ("gth-catalog-load-from-data", buffer);
@@ -1160,13 +1160,13 @@ gth_catalog_save (GthCatalog *catalog)
 	if (gio_parent != NULL)
 		g_file_make_directory_with_parents (gio_parent, NULL, NULL);
 	data = gth_catalog_to_data (catalog, &size);
-	if (! g_write_file (gio_file,
-			    FALSE,
-			    G_FILE_CREATE_NONE,
-			    data,
-			    size,
-			    NULL,
-			    &error))
+	if (! _g_file_write (gio_file,
+			     FALSE,
+			     G_FILE_CREATE_NONE,
+			     data,
+			     size,
+			     NULL,
+			     &error))
 	{
 		g_warning ("%s", error->message);
 		g_clear_error (&error);
diff --git a/extensions/catalogs/gth-file-source-catalogs.c b/extensions/catalogs/gth-file-source-catalogs.c
index bbd9612..f5f686f 100644
--- a/extensions/catalogs/gth-file-source-catalogs.c
+++ b/extensions/catalogs/gth-file-source-catalogs.c
@@ -253,14 +253,14 @@ write_metadata_load_buffer_ready_cb (void     **buffer,
 
 	catalog_buffer = gth_catalog_to_data (metadata_op->catalog, &catalog_size);
 	gio_file = gth_catalog_file_to_gio_file (metadata_op->file_data->file);
-	g_write_file_async (gio_file,
-			    catalog_buffer,
-			    catalog_size,
-			    TRUE,
-			    G_PRIORITY_DEFAULT,
-			    gth_file_source_get_cancellable (GTH_FILE_SOURCE (metadata_op->catalogs)),
-			    write_metadata_write_buffer_ready_cb,
-			    metadata_op);
+	_g_file_write_async (gio_file,
+			     catalog_buffer,
+			     catalog_size,
+			     TRUE,
+			     G_PRIORITY_DEFAULT,
+			     gth_file_source_get_cancellable (GTH_FILE_SOURCE (metadata_op->catalogs)),
+			     write_metadata_write_buffer_ready_cb,
+			     metadata_op);
 
 	g_object_unref (gio_file);
 }
@@ -301,11 +301,11 @@ gth_file_source_catalogs_write_metadata (GthFileSource *file_source,
 	metadata_op->catalog = gth_catalog_new ();
 	gio_file = gth_file_source_to_gio_file (file_source, file_data->file);
 	gth_catalog_set_file (metadata_op->catalog, gio_file);
-	g_load_file_async (gio_file,
-			   G_PRIORITY_DEFAULT,
-			   gth_file_source_get_cancellable (file_source),
-			   write_metadata_load_buffer_ready_cb,
-			   metadata_op);
+	_g_file_load_async (gio_file,
+			    G_PRIORITY_DEFAULT,
+			    gth_file_source_get_cancellable (file_source),
+			    write_metadata_load_buffer_ready_cb,
+			    metadata_op);
 
 	g_object_unref (gio_file);
 	g_free (uri);
@@ -837,14 +837,14 @@ catalog_ready_cb (GObject  *catalog,
 
 	buffer = gth_catalog_to_data (cod->catalog, &size);
 	gio_file = gth_catalog_file_to_gio_file (cod->destination->file);
-	g_write_file_async (gio_file,
-			    buffer,
-			    size,
-			    TRUE,
-			    G_PRIORITY_DEFAULT,
-			    NULL,
-			    copy__catalog_save_done_cb,
-			    cod);
+	_g_file_write_async (gio_file,
+			     buffer,
+			     size,
+			     TRUE,
+			     G_PRIORITY_DEFAULT,
+			     NULL,
+			     copy__catalog_save_done_cb,
+			     cod);
 
 	g_object_unref (gio_file);
 }
@@ -1255,14 +1255,14 @@ reorder_catalog_ready_cb (GObject  *object,
 
 	buffer = gth_catalog_to_data (catalog, &size);
 	gio_file = gth_file_source_to_gio_file (reorder_data->file_source, reorder_data->destination->file);
-	g_write_file_async (gio_file,
-			    buffer,
-			    size,
-			    TRUE,
-			    G_PRIORITY_DEFAULT,
-			    gth_file_source_get_cancellable (reorder_data->file_source),
-			    reorder_buffer_ready_cb,
-			    reorder_data);
+	_g_file_write_async (gio_file,
+			     buffer,
+			     size,
+			     TRUE,
+			     G_PRIORITY_DEFAULT,
+			     gth_file_source_get_cancellable (reorder_data->file_source),
+			     reorder_buffer_ready_cb,
+			     reorder_data);
 
 	g_object_unref (gio_file);
 }
@@ -1399,14 +1399,14 @@ catalog_buffer_ready_cb (void     **buffer,
 		return;
 	}
 
-	g_write_file_async (data->gio_file,
-			    catalog_buffer,
-			    catalog_size,
-			    TRUE,
-			    G_PRIORITY_DEFAULT,
-			    NULL,
-			    remove_files__catalog_save_done_cb,
-			    data);
+	_g_file_write_async (data->gio_file,
+			     catalog_buffer,
+			     catalog_size,
+			     TRUE,
+			     G_PRIORITY_DEFAULT,
+			     NULL,
+			     remove_files__catalog_save_done_cb,
+			     data);
 }
 
 
@@ -1422,11 +1422,11 @@ gth_catalog_manager_remove_files (GtkWindow   *parent,
 	data->file_data_list = gth_file_data_list_dup (file_list);
 	data->gio_file = gth_main_get_gio_file (location->file);
 
-	g_load_file_async (data->gio_file,
-			   G_PRIORITY_DEFAULT,
-			   NULL,
-			   catalog_buffer_ready_cb,
-			   data);
+	_g_file_load_async (data->gio_file,
+			    G_PRIORITY_DEFAULT,
+			    NULL,
+			    catalog_buffer_ready_cb,
+			    data);
 }
 
 
diff --git a/extensions/comments/gth-comment.c b/extensions/comments/gth-comment.c
index 1e6ceef..df7bd80 100644
--- a/extensions/comments/gth-comment.c
+++ b/extensions/comments/gth-comment.c
@@ -289,7 +289,7 @@ gth_comment_new_for_file (GFile         *file,
 	if (comment_file == NULL)
 		return NULL;
 
-	if (! g_load_file_in_buffer (comment_file, &zipped_buffer, &zipped_size, cancellable, error)) {
+	if (! _g_file_load_in_buffer (comment_file, &zipped_buffer, &zipped_size, cancellable, error)) {
 		g_object_unref (comment_file);
 		return NULL;
 	}
@@ -704,13 +704,13 @@ gth_comment_synchronize_metadata (GList *file_list)
 				g_file_make_directory (comment_directory, NULL, NULL);
 
 			buffer = gth_comment_to_data (comment, &size);
-			g_write_file (comment_file,
-				      FALSE,
-				      G_FILE_CREATE_NONE,
-				      buffer,
-				      size,
-				      NULL,
-				      NULL);
+			_g_file_write (comment_file,
+				       FALSE,
+				       G_FILE_CREATE_NONE,
+				       buffer,
+				       size,
+				       NULL,
+				       NULL);
 
 			{
 				GFile *parent;
diff --git a/extensions/comments/gth-import-metadata-task.c b/extensions/comments/gth-import-metadata-task.c
index 49044a7..cd4f065 100644
--- a/extensions/comments/gth-import-metadata-task.c
+++ b/extensions/comments/gth-import-metadata-task.c
@@ -117,14 +117,14 @@ load_file_ready_cb (void     **buffer,
 
 	gth_hook_invoke ("delete-metadata", file, &tmp_buffer, &count);
 
-	g_write_file_async (file,
-			    tmp_buffer,
-	    		    count,
-	    		    TRUE,
-	    		    G_PRIORITY_DEFAULT,
-	    		    gth_task_get_cancellable (GTH_TASK (self)),
-			    write_file_ready_cb,
-			    self);
+	_g_file_write_async (file,
+			     tmp_buffer,
+	    		     count,
+	    		     TRUE,
+	    		     G_PRIORITY_DEFAULT,
+	    		     gth_task_get_cancellable (GTH_TASK (self)),
+			     write_file_ready_cb,
+			     self);
 }
 
 
@@ -139,11 +139,11 @@ import_current_file (GthImportMetadataTask *self)
 	}
 
 	file = self->priv->current->data;
-	g_load_file_async (file,
-			   G_PRIORITY_DEFAULT,
-			   gth_task_get_cancellable (GTH_TASK (self)),
-			   load_file_ready_cb,
-			   self);
+	_g_file_load_async (file,
+			    G_PRIORITY_DEFAULT,
+			    gth_task_get_cancellable (GTH_TASK (self)),
+			    load_file_ready_cb,
+			    self);
 }
 
 
diff --git a/extensions/comments/gth-metadata-provider-comment.c b/extensions/comments/gth-metadata-provider-comment.c
index bae882f..03c9553 100644
--- a/extensions/comments/gth-metadata-provider-comment.c
+++ b/extensions/comments/gth-metadata-provider-comment.c
@@ -209,7 +209,7 @@ gth_metadata_provider_comment_write (GthMetadataProvider   *self,
 	comment_folder = g_file_get_parent (comment_file);
 
 	g_file_make_directory (comment_folder, NULL, NULL);
-	g_write_file (comment_file, FALSE, 0, data, length, cancellable, NULL);
+	_g_file_write (comment_file, FALSE, 0, data, length, cancellable, NULL);
 
 	g_object_unref (comment_folder);
 	g_object_unref (comment_file);
diff --git a/extensions/contact_sheet/dlg-contact-sheet.c b/extensions/contact_sheet/dlg-contact-sheet.c
index 8c9e903..eb50973 100644
--- a/extensions/contact_sheet/dlg-contact-sheet.c
+++ b/extensions/contact_sheet/dlg-contact-sheet.c
@@ -323,11 +323,11 @@ add_themes_from_dir (DialogData *data,
 		}
 
 		file = g_file_get_child (dir, g_file_info_get_name (file_info));
-		if (! g_load_file_in_buffer (file,
-					     (void **) &buffer,
-					     &size,
-					     NULL,
-					     NULL))
+		if (! _g_file_load_in_buffer (file,
+					      (void **) &buffer,
+					      &size,
+					      NULL,
+					      NULL))
 		{
 			g_object_unref (file);
 			g_object_unref (file_info);
@@ -495,13 +495,13 @@ theme_dialog_response_cb (GtkDialog *dialog,
 		return;
 	}
 
-	if (! g_write_file (theme->file,
-			    FALSE,
-			    G_FILE_CREATE_NONE,
-			    buffer,
-			    buffer_size,
-			    NULL,
-			    &error))
+	if (! _g_file_write (theme->file,
+			     FALSE,
+			     G_FILE_CREATE_NONE,
+			     buffer,
+			     buffer_size,
+			     NULL,
+			     &error))
 	{
 		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (data->dialog), _("Could not save the theme"), error);
 		g_clear_error (&error);
diff --git a/extensions/contact_sheet/gth-contact-sheet-creator.c b/extensions/contact_sheet/gth-contact-sheet-creator.c
index f0797ff..45d8f70 100644
--- a/extensions/contact_sheet/gth-contact-sheet-creator.c
+++ b/extensions/contact_sheet/gth-contact-sheet-creator.c
@@ -365,13 +365,13 @@ end_page (GthContactSheetCreator  *self,
 		return FALSE;
 	}
 
-	if (! g_write_file (self->priv->destination_file,
-			    FALSE,
-			    G_FILE_CREATE_REPLACE_DESTINATION,
-			    buffer,
-			    size,
-			    gth_task_get_cancellable (GTH_TASK (self)),
-			    error))
+	if (! _g_file_write (self->priv->destination_file,
+			     FALSE,
+			     G_FILE_CREATE_REPLACE_DESTINATION,
+			     buffer,
+			     size,
+			     gth_task_get_cancellable (GTH_TASK (self)),
+			     error))
 	{
 		g_object_unref (pixbuf);
 		return FALSE;
diff --git a/extensions/edit_metadata/gth-delete-metadata-task.c b/extensions/edit_metadata/gth-delete-metadata-task.c
index 6e02e81..27df110 100644
--- a/extensions/edit_metadata/gth-delete-metadata-task.c
+++ b/extensions/edit_metadata/gth-delete-metadata-task.c
@@ -115,14 +115,14 @@ load_file_ready_cb (void     **buffer,
 
 	gth_hook_invoke ("delete-metadata", file, &tmp_buffer, &count);
 
-	g_write_file_async (file,
-			    tmp_buffer,
-	    		    count,
-	    		    TRUE,
-	    		    G_PRIORITY_DEFAULT,
-	    		    gth_task_get_cancellable (GTH_TASK (self)),
-			    write_file_ready_cb,
-			    self);
+	_g_file_write_async (file,
+			     tmp_buffer,
+	    		     count,
+	    		     TRUE,
+	    		     G_PRIORITY_DEFAULT,
+	    		     gth_task_get_cancellable (GTH_TASK (self)),
+			     write_file_ready_cb,
+			     self);
 }
 
 
@@ -137,11 +137,11 @@ transform_current_file (GthDeleteMetadataTask *self)
 	}
 
 	file = self->priv->current->data;
-	g_load_file_async (file,
-			   G_PRIORITY_DEFAULT,
-			   gth_task_get_cancellable (GTH_TASK (self)),
-			   load_file_ready_cb,
-			   self);
+	_g_file_load_async (file,
+			    G_PRIORITY_DEFAULT,
+			    gth_task_get_cancellable (GTH_TASK (self)),
+			    load_file_ready_cb,
+			    self);
 }
 
 
diff --git a/extensions/exiv2_tools/gth-metadata-provider-exiv2.c b/extensions/exiv2_tools/gth-metadata-provider-exiv2.c
index 32402f2..0c15634 100644
--- a/extensions/exiv2_tools/gth-metadata-provider-exiv2.c
+++ b/extensions/exiv2_tools/gth-metadata-provider-exiv2.c
@@ -148,7 +148,7 @@ gth_metadata_provider_exiv2_write (GthMetadataProvider   *base,
 	if (! exiv2_supports_writes (gth_file_data_get_mime_type (file_data)))
 		return;
 
-	if (! g_load_file_in_buffer (file_data->file, &buffer, &size, cancellable, &error))
+	if (! _g_file_load_in_buffer (file_data->file, &buffer, &size, cancellable, &error))
 		return;
 
 	metadata = g_file_info_get_attribute_object (file_data->info, "general::description");
@@ -284,13 +284,13 @@ gth_metadata_provider_exiv2_write (GthMetadataProvider   *base,
 	{
 		GFileInfo *tmp_info;
 
-		g_write_file (file_data->file,
-			      FALSE,
-			      G_FILE_CREATE_NONE,
-			      buffer,
-			      size,
-			      cancellable,
-			      &error);
+		_g_file_write (file_data->file,
+			       FALSE,
+			       G_FILE_CREATE_NONE,
+			       buffer,
+			       size,
+			       cancellable,
+			       &error);
 
 		tmp_info = g_file_info_new ();
 		g_file_info_set_attribute_uint64 (tmp_info,
diff --git a/extensions/facebook/facebook-service.c b/extensions/facebook/facebook-service.c
index dce10b1..06753fc 100644
--- a/extensions/facebook/facebook-service.c
+++ b/extensions/facebook/facebook-service.c
@@ -840,11 +840,11 @@ facebook_service_upload_current_file (FacebookService *self)
 	}
 
 	file_data = self->priv->post_photos->current->data;
-	g_load_file_async (file_data->file,
-			   G_PRIORITY_DEFAULT,
-			   self->priv->post_photos->cancellable,
-			   upload_photo_file_buffer_ready_cb,
-			   self);
+	_g_file_load_async (file_data->file,
+			    G_PRIORITY_DEFAULT,
+			    self->priv->post_photos->cancellable,
+			    upload_photo_file_buffer_ready_cb,
+			    self);
 }
 
 
@@ -1059,7 +1059,7 @@ facebook_accounts_load_from_file (void)
 	DomDocument *doc;
 
 	file = gth_user_dir_get_file_for_read (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", "facebook.xml", NULL);
-	if (! g_load_file_in_buffer (file, (void **) &buffer, &len, NULL, NULL)) {
+	if (! _g_file_load_in_buffer (file, (void **) &buffer, &len, NULL, NULL)) {
 		g_object_unref (file);
 		return NULL;
 	}
@@ -1142,7 +1142,7 @@ facebook_accounts_save_to_file (GList         *accounts,
 
 	file = gth_user_dir_get_file_for_write (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", "facebook.xml", NULL);
 	buffer = dom_document_dump (doc, &len);
-	g_write_file (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
+	_g_file_write (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
 
 	g_free (buffer);
 	g_object_unref (file);
diff --git a/extensions/flicker_utils/dlg-import-from-flickr.c b/extensions/flicker_utils/dlg-import-from-flickr.c
index 3bca374..25bd953 100644
--- a/extensions/flicker_utils/dlg-import-from-flickr.c
+++ b/extensions/flicker_utils/dlg-import-from-flickr.c
@@ -450,7 +450,7 @@ flickr_thumbnail_loader (GthFileData   *file_data,
 		gsize  size;
 
 		file = g_file_new_for_uri (uri);
-		if (g_load_file_in_buffer (file, &buffer, &size, cancellable, error)) {
+		if (_g_file_load_in_buffer (file, &buffer, &size, cancellable, error)) {
 			GInputStream *stream;
 			GdkPixbuf    *pixbuf;
 
diff --git a/extensions/flicker_utils/flickr-service.c b/extensions/flicker_utils/flickr-service.c
index 2e8a0a3..79fc0ac 100644
--- a/extensions/flicker_utils/flickr-service.c
+++ b/extensions/flicker_utils/flickr-service.c
@@ -867,11 +867,11 @@ flickr_service_post_current_file (FlickrService *self)
 	}
 
 	file_data = self->priv->post_photos->current->data;
-	g_load_file_async (file_data->file,
-			   G_PRIORITY_DEFAULT,
-			   self->priv->post_photos->cancellable,
-			   post_photo_file_buffer_ready_cb,
-			   self);
+	_g_file_load_async (file_data->file,
+			    G_PRIORITY_DEFAULT,
+			    self->priv->post_photos->cancellable,
+			    post_photo_file_buffer_ready_cb,
+			    self);
 }
 
 
@@ -1177,7 +1177,7 @@ flickr_accounts_load_from_file (const char *server_name)
 	file = gth_user_dir_get_file_for_read (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", accounts_filename, NULL);
 	g_free (accounts_filename);
 
-	if (! g_load_file_in_buffer (file, (void **) &buffer, &len, NULL, NULL)) {
+	if (! _g_file_load_in_buffer (file, (void **) &buffer, &len, NULL, NULL)) {
 		g_object_unref (file);
 		return NULL;
 	}
@@ -1263,7 +1263,7 @@ flickr_accounts_save_to_file (const char    *server_name,
 	accounts_filename = get_server_accounts_filename (server_name);
 	file = gth_user_dir_get_file_for_write (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", accounts_filename, NULL);
 	buffer = dom_document_dump (doc, &len);
-	g_write_file (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
+	_g_file_write (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
 
 	g_free (buffer);
 	g_object_unref (file);
diff --git a/extensions/image_rotation/rotation-utils.c b/extensions/image_rotation/rotation-utils.c
index b32b7b5..6121bfd 100644
--- a/extensions/image_rotation/rotation-utils.c
+++ b/extensions/image_rotation/rotation-utils.c
@@ -298,14 +298,14 @@ file_buffer_ready_cb (void     **buffer,
 			return;
 		}
 
-		g_write_file_async (tdata->file_data->file,
-				    out_buffer,
-		    		    out_buffer_size,
-		    		    TRUE,
-				    G_PRIORITY_DEFAULT,
-				    tdata->cancellable,
-				    write_file_ready_cb,
-				    tdata);
+		_g_file_write_async (tdata->file_data->file,
+				     out_buffer,
+		    		     out_buffer_size,
+		    		     TRUE,
+				     G_PRIORITY_DEFAULT,
+				     tdata->cancellable,
+				     write_file_ready_cb,
+				     tdata);
 	}
 	else
 #endif /* HAVE_LIBJPEG */
@@ -360,9 +360,9 @@ apply_transformation_async (GthFileData   *file_data,
 	tdata->ready_func = ready_func;
 	tdata->user_data = user_data;
 
-	g_load_file_async (tdata->file_data->file,
-			   G_PRIORITY_DEFAULT,
-			   tdata->cancellable,
-			   file_buffer_ready_cb,
-			   tdata);
+	_g_file_load_async (tdata->file_data->file,
+			    G_PRIORITY_DEFAULT,
+			    tdata->cancellable,
+			    file_buffer_ready_cb,
+			    tdata);
 }
diff --git a/extensions/list_tools/gth-script-file.c b/extensions/list_tools/gth-script-file.c
index 7e9a129..b5465b3 100644
--- a/extensions/list_tools/gth-script-file.c
+++ b/extensions/list_tools/gth-script-file.c
@@ -165,7 +165,7 @@ gth_script_file_load_from_file (GthScriptFile  *self,
 	g_return_val_if_fail (file != NULL, FALSE);
 
 	read_error = NULL;
-	g_load_file_in_buffer (file, (void **) &buffer, &len, NULL, &read_error);
+	_g_file_load_in_buffer (file, (void **) &buffer, &len, NULL, &read_error);
 	if (read_error != NULL) {
 		g_propagate_error (error, read_error);
 		return FALSE;
@@ -250,7 +250,7 @@ gth_script_file_to_file (GthScriptFile  *self,
 	}
 
 	write_error = NULL;
-	if (! g_write_file (file, FALSE, 0, data, len, NULL, &write_error)) {
+	if (! _g_file_write (file, FALSE, 0, data, len, NULL, &write_error)) {
 		g_propagate_error (error, write_error);
 		retval = FALSE;
 	}
diff --git a/extensions/oauth/oauth-authentication.c b/extensions/oauth/oauth-authentication.c
index 58810a6..c398693 100644
--- a/extensions/oauth/oauth-authentication.c
+++ b/extensions/oauth/oauth-authentication.c
@@ -735,7 +735,7 @@ oauth_accounts_load_from_file (const char *service_name,
 
 	filename = g_strconcat (service_name, ".xml", NULL);
 	file = gth_user_dir_get_file_for_read (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", filename, NULL);
-	if (! g_load_file_in_buffer (file, (void **) &buffer, &len, NULL, &error)) {
+	if (! _g_file_load_in_buffer (file, (void **) &buffer, &len, NULL, &error)) {
 		g_warning ("%s\n", error->message);
 		g_error_free (error);
 		g_object_unref (file);
@@ -825,7 +825,7 @@ oauth_accounts_save_to_file (const char   *service_name,
 	filename = g_strconcat (service_name, ".xml", NULL);
 	file = gth_user_dir_get_file_for_write (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", filename, NULL);
 	buffer = dom_document_dump (doc, &len);
-	g_write_file (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
+	_g_file_write (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
 
 	g_free (buffer);
 	g_object_unref (file);
diff --git a/extensions/photobucket/photobucket-service.c b/extensions/photobucket/photobucket-service.c
index 69d7131..a48af6a 100644
--- a/extensions/photobucket/photobucket-service.c
+++ b/extensions/photobucket/photobucket-service.c
@@ -551,11 +551,11 @@ photobucket_service_upload_current_file (PhotobucketService *self)
 	}
 
 	file_data = self->priv->post_photos->current->data;
-	g_load_file_async (file_data->file,
-			   G_PRIORITY_DEFAULT,
-			   self->priv->post_photos->cancellable,
-			   upload_photo_file_buffer_ready_cb,
-			   self);
+	_g_file_load_async (file_data->file,
+			    G_PRIORITY_DEFAULT,
+			    self->priv->post_photos->cancellable,
+			    upload_photo_file_buffer_ready_cb,
+			    self);
 }
 
 
diff --git a/extensions/picasaweb/dlg-import-from-picasaweb.c b/extensions/picasaweb/dlg-import-from-picasaweb.c
index a4d7d87..6ef4659 100644
--- a/extensions/picasaweb/dlg-import-from-picasaweb.c
+++ b/extensions/picasaweb/dlg-import-from-picasaweb.c
@@ -916,7 +916,7 @@ picasa_web_thumbnail_loader (GthFileData   *file_data,
 		gsize  size;
 
 		file = g_file_new_for_uri (uri);
-		if (g_load_file_in_buffer (file, &buffer, &size, cancellable, error)) {
+		if (_g_file_load_in_buffer (file, &buffer, &size, cancellable, error)) {
 			GInputStream *stream;
 			GdkPixbuf    *pixbuf;
 
diff --git a/extensions/picasaweb/picasa-account-properties-dialog.c b/extensions/picasaweb/picasa-account-properties-dialog.c
index 44911db..e0fd76c 100644
--- a/extensions/picasaweb/picasa-account-properties-dialog.c
+++ b/extensions/picasaweb/picasa-account-properties-dialog.c
@@ -135,11 +135,11 @@ picasa_account_properties_dialog_construct (PicasaAccountPropertiesDialog *self,
 
 		url = g_strconcat ("http://www.google.com/accounts/";, challange_url, NULL);
 		file = g_file_new_for_uri (url);
-		g_load_file_async (file,
-				   G_PRIORITY_DEFAULT,
-				   self->priv->cancellable,
-				   image_buffer_ready_cb,
-				   self);
+		_g_file_load_async (file,
+				    G_PRIORITY_DEFAULT,
+				    self->priv->cancellable,
+				    image_buffer_ready_cb,
+				    self);
 
 		g_object_unref (file);
 		g_free (url);
diff --git a/extensions/picasaweb/picasa-web-service.c b/extensions/picasaweb/picasa-web-service.c
index bfe69a2..a7b9499 100644
--- a/extensions/picasaweb/picasa-web-service.c
+++ b/extensions/picasaweb/picasa-web-service.c
@@ -555,11 +555,11 @@ picasa_wev_service_post_current_file (PicasaWebService *self)
 	}
 
 	file_data = self->priv->post_photos->current->data;
-	g_load_file_async (file_data->file,
-			   G_PRIORITY_DEFAULT,
-			   self->priv->post_photos->cancellable,
-			   post_photo_file_buffer_ready_cb,
-			   self);
+	_g_file_load_async (file_data->file,
+			    G_PRIORITY_DEFAULT,
+			    self->priv->post_photos->cancellable,
+			    post_photo_file_buffer_ready_cb,
+			    self);
 }
 
 
@@ -761,7 +761,7 @@ picasa_web_accounts_load_from_file (char **_default)
 	DomDocument *doc;
 
 	file = gth_user_dir_get_file_for_read (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", "picasaweb.xml", NULL);
-	if (! g_load_file_in_buffer (file, (void **) &buffer, &len, NULL, NULL)) {
+	if (! _g_file_load_in_buffer (file, (void **) &buffer, &len, NULL, NULL)) {
 		g_object_unref (file);
 		return NULL;
 	}
@@ -829,7 +829,7 @@ picasa_web_accounts_save_to_file (GList      *accounts,
 
 	file = gth_user_dir_get_file_for_write (GTH_DIR_CONFIG, GTHUMB_DIR, "accounts", "picasaweb.xml", NULL);
 	buffer = dom_document_dump (doc, &len);
-	g_write_file (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
+	_g_file_write (file, FALSE, G_FILE_CREATE_PRIVATE | G_FILE_CREATE_REPLACE_DESTINATION, buffer, len, NULL, NULL);
 
 	g_free (buffer);
 	g_object_unref (file);
diff --git a/extensions/search/actions.c b/extensions/search/actions.c
index c57c8c9..a3e1ee9 100644
--- a/extensions/search/actions.c
+++ b/extensions/search/actions.c
@@ -149,11 +149,11 @@ gth_browser_activate_action_edit_search_update (GtkAction  *action,
 	search_data->file = g_file_dup (location);
 
 	file = gth_main_get_gio_file (location);
-	g_load_file_async (file,
-			   G_PRIORITY_DEFAULT,
-			   NULL,
-			   search_update_buffer_ready_cb,
-			   search_data);
+	_g_file_load_async (file,
+			    G_PRIORITY_DEFAULT,
+			    NULL,
+			    search_update_buffer_ready_cb,
+			    search_data);
 
 	g_object_unref (file);
 }
diff --git a/extensions/search/gth-search-task.c b/extensions/search/gth-search-task.c
index 4db11a7..16f37ce 100644
--- a/extensions/search/gth-search-task.c
+++ b/extensions/search/gth-search-task.c
@@ -157,14 +157,14 @@ done_func (GObject  *object,
 	data = dom_document_dump (doc, &size);
 
 	search_result_real_file = gth_catalog_file_to_gio_file (task->priv->search_catalog);
-	g_write_file_async (search_result_real_file,
-			    data,
-			    size,
-			    TRUE,
-			    G_PRIORITY_DEFAULT,
-			    gth_task_get_cancellable (GTH_TASK (task)),
-			    save_search_result_copy_done_cb,
-			    task);
+	_g_file_write_async (search_result_real_file,
+			     data,
+			     size,
+			     TRUE,
+			     G_PRIORITY_DEFAULT,
+			     gth_task_get_cancellable (GTH_TASK (task)),
+			     save_search_result_copy_done_cb,
+			     task);
 
 	g_object_unref (search_result_real_file);
 	g_object_unref (doc);
@@ -395,14 +395,14 @@ gth_search_task_exec (GthTask *base)
 	data = dom_document_dump (doc, &size);
 
 	search_result_real_file = gth_catalog_file_to_gio_file (task->priv->search_catalog);
-	g_write_file_async (search_result_real_file,
-			    data,
-			    size,
-			    TRUE,
-			    G_PRIORITY_DEFAULT,
-			    gth_task_get_cancellable (GTH_TASK (task)),
-			    clear_search_result_copy_done_cb,
-			    task);
+	_g_file_write_async (search_result_real_file,
+			     data,
+			     size,
+			     TRUE,
+			     G_PRIORITY_DEFAULT,
+			     gth_task_get_cancellable (GTH_TASK (task)),
+			     clear_search_result_copy_done_cb,
+			     task);
 
 	g_object_unref (search_result_real_file);
 	g_object_unref (doc);
diff --git a/gthumb/gio-utils.c b/gthumb/gio-utils.c
index 3fedbf8..87d5b42 100644
--- a/gthumb/gio-utils.c
+++ b/gthumb/gio-utils.c
@@ -1934,11 +1934,11 @@ _g_delete_files_async (GList        *file_list,
 
 
 gboolean
-g_load_file_in_buffer (GFile         *file,
-		       void         **buffer,
-		       gsize         *size,
-		       GCancellable  *cancellable,
-		       GError       **error)
+_g_file_load_in_buffer (GFile         *file,
+		        void         **buffer,
+		        gsize         *size,
+		        GCancellable  *cancellable,
+		        GError       **error)
 {
 	GFileInputStream *istream;
 	gboolean          retval;
@@ -2071,11 +2071,11 @@ load_file__file_read_cb (GObject      *source_object,
 
 
 void
-g_load_file_async (GFile               *file,
-		   int                  io_priority,
-		   GCancellable        *cancellable,
-		   BufferReadyCallback  callback,
-		   gpointer             user_data)
+_g_file_load_async (GFile               *file,
+		    int                  io_priority,
+		    GCancellable        *cancellable,
+		    BufferReadyCallback  callback,
+		    gpointer             user_data)
 {
 	LoadData *load_data;
 
@@ -2089,7 +2089,7 @@ g_load_file_async (GFile               *file,
 }
 
 
-/* -- g_write_file_async -- */
+/* -- _g_file_write_async -- */
 
 
 typedef struct {
@@ -2226,14 +2226,14 @@ write_file__create_ready_cb (GObject      *source_object,
 
 
 void
-g_write_file_async (GFile               *file,
-		    void                *buffer,
-		    gsize                count,
-		    gboolean             replace,
-		    int                  io_priority,
-		    GCancellable        *cancellable,
-		    BufferReadyCallback  callback,
-		    gpointer             user_data)
+_g_file_write_async (GFile               *file,
+		     void                *buffer,
+		     gsize                count,
+		     gboolean             replace,
+		     int                  io_priority,
+		     GCancellable        *cancellable,
+		     BufferReadyCallback  callback,
+		     gpointer             user_data)
 {
 	WriteData *write_data;
 
@@ -2398,17 +2398,17 @@ _g_directory_create_tmp (void)
 }
 
 
-/* -- g_write_file -- */
+/* -- _g_file_write -- */
 
 
 gboolean
-g_write_file (GFile             *file,
-	      gboolean           make_backup,
-	      GFileCreateFlags   flags,
-	      void              *buffer,
-	      gsize              count,
-	      GCancellable      *cancellable,
-	      GError           **error)
+_g_file_write (GFile             *file,
+	       gboolean           make_backup,
+	       GFileCreateFlags   flags,
+	       void              *buffer,
+	       gsize              count,
+	       GCancellable      *cancellable,
+	       GError           **error)
 {
 	gboolean       success;
 	GOutputStream *stream;
diff --git a/gthumb/gio-utils.h b/gthumb/gio-utils.h
index 306dddf..a8a3523 100644
--- a/gthumb/gio-utils.h
+++ b/gthumb/gio-utils.h
@@ -148,24 +148,24 @@ void     _g_delete_files_async       (GList                  *file_list,
 
 /* -- load/write/create file  -- */
 
-gboolean g_load_file_in_buffer       (GFile                 *file,
+gboolean _g_file_load_in_buffer      (GFile                 *file,
 				      void                 **buffer,
 				      gsize                 *size,
 				      GCancellable          *cancellable,
 				      GError               **error);
-void     g_load_file_async           (GFile                 *file,
+void     _g_file_load_async          (GFile                 *file,
 				      int                    io_priority,
 				      GCancellable          *cancellable,
 				      BufferReadyCallback    callback,
 				      gpointer               user_data);
-gboolean g_write_file                (GFile                 *file,
+gboolean _g_file_write               (GFile                 *file,
 				      gboolean               make_backup,
 			              GFileCreateFlags       flags,
 				      void                  *buffer,
 				      gsize                  count,
 				      GCancellable          *cancellable,
 				      GError               **error);
-void     g_write_file_async          (GFile                 *file,
+void     _g_file_write_async         (GFile                 *file,
 				      void                  *buffer,
 		    		      gsize                  count,
 		    		      gboolean               replace,
diff --git a/gthumb/gth-filter-file.c b/gthumb/gth-filter-file.c
index 0fd0609..c3c178f 100644
--- a/gthumb/gth-filter-file.c
+++ b/gthumb/gth-filter-file.c
@@ -124,7 +124,7 @@ gth_filter_file_load_from_file (GthFilterFile  *filters,
 	g_return_val_if_fail (file != NULL, FALSE);
 
 	read_error = NULL;
-	if (! g_load_file_in_buffer (file, (void **) &buffer, &len, NULL, &read_error)) {
+	if (! _g_file_load_in_buffer (file, (void **) &buffer, &len, NULL, &read_error)) {
 		g_propagate_error (error, read_error);
 		return FALSE;
 	}
@@ -192,7 +192,7 @@ gth_filter_file_to_file (GthFilterFile  *filters,
 	}
 
 	write_error = NULL;
-	if (! g_write_file (file, FALSE, 0, data, len, NULL, &write_error)) {
+	if (! _g_file_write (file, FALSE, 0, data, len, NULL, &write_error)) {
 		g_propagate_error (error, write_error);
 		retval = FALSE;
 	}
diff --git a/gthumb/gth-pixbuf-list-task.c b/gthumb/gth-pixbuf-list-task.c
index 2ebf1d3..59dead2 100644
--- a/gthumb/gth-pixbuf-list-task.c
+++ b/gthumb/gth-pixbuf-list-task.c
@@ -402,11 +402,11 @@ file_info_ready_cb (GList    *files,
 	updated_file_data = (GthFileData*) files->data;
 	g_file_info_copy_into (updated_file_data->info, source_file_data->info);
 
-	g_load_file_async (source_file_data->file,
-			   G_PRIORITY_DEFAULT,
-			   gth_task_get_cancellable (GTH_TASK (self)),
-			   file_buffer_ready_cb,
-			   self);
+	_g_file_load_async (source_file_data->file,
+			    G_PRIORITY_DEFAULT,
+			    gth_task_get_cancellable (GTH_TASK (self)),
+			    file_buffer_ready_cb,
+			    self);
 }
 
 
diff --git a/gthumb/gth-tags-file.c b/gthumb/gth-tags-file.c
index 6642203..59a0162 100644
--- a/gthumb/gth-tags-file.c
+++ b/gthumb/gth-tags-file.c
@@ -119,7 +119,7 @@ gth_tags_file_load_from_file (GthTagsFile  *tags,
 	g_return_val_if_fail (file != NULL, FALSE);
 
 	read_error = NULL;
-	if (! g_load_file_in_buffer (file, (void **) &buffer, &len, NULL, &read_error)) {
+	if (! _g_file_load_in_buffer (file, (void **) &buffer, &len, NULL, &read_error)) {
 		g_propagate_error (error, read_error);
 		return FALSE;
 	}
@@ -189,7 +189,7 @@ gth_tags_file_to_file (GthTagsFile  *tags,
 	}
 
 	write_error = NULL;
-	if (! g_write_file (file, FALSE, 0, data, len, NULL, &write_error)) {
+	if (! _g_file_write (file, FALSE, 0, data, len, NULL, &write_error)) {
 		g_propagate_error (error, write_error);
 		retval = FALSE;
 	}
diff --git a/gthumb/main-migrate-catalogs.c b/gthumb/main-migrate-catalogs.c
index 6d1952b..fb0f28b 100644
--- a/gthumb/main-migrate-catalogs.c
+++ b/gthumb/main-migrate-catalogs.c
@@ -95,11 +95,11 @@ migration_for_each_file (GFile     *file,
 	if (g_file_info_get_file_type (info) != G_FILE_TYPE_REGULAR)
 		return;
 
-	if (! g_load_file_in_buffer (file,
-				     (void **) &buffer,
-				     &buffer_size,
-				     NULL,
-				     &error))
+	if (! _g_file_load_in_buffer (file,
+				      (void **) &buffer,
+				      &buffer_size,
+				      NULL,
+				      &error))
 	{
 		g_warning ("%s", error->message);
 		return;
@@ -446,13 +446,13 @@ migration_for_each_file (GFile     *file,
 	*/
 
 	if (! g_file_query_exists (catalog_file, NULL)) {
-		if (! g_write_file (catalog_file,
-				    FALSE,
-				    G_FILE_CREATE_PRIVATE,
-				    new_buffer,
-				    new_buffer_size,
-				    NULL,
-				    &error))
+		if (! _g_file_write (catalog_file,
+				     FALSE,
+				     G_FILE_CREATE_PRIVATE,
+				     new_buffer,
+				     new_buffer_size,
+				     NULL,
+				     &error))
 		{
 			g_warning ("%s", error->message);
 		}
diff --git a/gthumb/pixbuf-io.c b/gthumb/pixbuf-io.c
index f6534f3..dc30a0d 100644
--- a/gthumb/pixbuf-io.c
+++ b/gthumb/pixbuf-io.c
@@ -126,14 +126,14 @@ save_current_file (SaveData *save_data)
 	}
 
 	file = save_data->current->data;
-	g_write_file_async (file->file,
-			    file->buffer,
-			    file->buffer_size,
-			    (g_file_equal (save_data->data->file_data->file, file->file) ? save_data->data->replace : TRUE),
-			    G_PRIORITY_DEFAULT,
-			    NULL,
-			    file_saved_cb,
-			    save_data);
+	_g_file_write_async (file->file,
+			     file->buffer,
+			     file->buffer_size,
+			     (g_file_equal (save_data->data->file_data->file, file->file) ? save_data->data->replace : TRUE),
+			     G_PRIORITY_DEFAULT,
+			     NULL,
+			     file_saved_cb,
+			     save_data);
 }
 
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/extensions/importer/gth-import-task.c b/extensions/importer/gth-import-task.c
index 0586030..6a21869 100644
--- a/extensions/importer/gth-import-task.c
+++ b/extensions/importer/gth-import-task.c
@@ -482,16 +482,16 @@ write_file_to_destination (GthImportTask *self,
 				   FALSE,
 				   (double) (self->priv->copied_size + ((double) self->priv->current_file_size / 3.0 * 2.0)) / self->priv->tot_size);
 
-		self->priv->buffer = NULL; /* the buffer will be deallocated in g_write_file_async */
+		self->priv->buffer = NULL; /* the buffer will be deallocated in _g_file_write_async */
 
-		g_write_file_async (self->priv->destination_file->file,
-				    buffer,
-				    count,
-				    replace,
-				    G_PRIORITY_DEFAULT,
-				    gth_task_get_cancellable (GTH_TASK (self)),
-				    write_buffer_ready_cb,
-				    self);
+		_g_file_write_async (self->priv->destination_file->file,
+				     buffer,
+				     count,
+				     replace,
+				     G_PRIORITY_DEFAULT,
+				     gth_task_get_cancellable (GTH_TASK (self)),
+				     write_buffer_ready_cb,
+				     self);
 	}
 	else
 		g_file_copy_async (file_data->file,
@@ -575,7 +575,7 @@ file_buffer_ready_cb (void     **buffer,
 				   *buffer,
 				   count,
 				   self->priv->default_response == GTH_OVERWRITE_RESPONSE_ALWAYS_YES);
-	*buffer = NULL; /* g_write_file_async takes ownership of the buffer */
+	*buffer = NULL; /* _g_file_write_async takes ownership of the buffer */
 
 	g_object_unref (destination_file);
 }
@@ -653,11 +653,11 @@ import_current_file (GthImportTask *self)
 				   FALSE,
 				   (double) (self->priv->copied_size + ((double) self->priv->current_file_size / 3.0)) / self->priv->tot_size);
 
-		g_load_file_async (file_data->file,
-				   G_PRIORITY_DEFAULT,
-				   gth_task_get_cancellable (GTH_TASK (self)),
-				   file_buffer_ready_cb,
-				   self);
+		_g_file_load_async (file_data->file,
+				    G_PRIORITY_DEFAULT,
+				    gth_task_get_cancellable (GTH_TASK (self)),
+				    file_buffer_ready_cb,
+				    self);
 	}
 	else {
 		GFile *destination_file;